@@ -24,8 +24,8 @@ class FetchEvent(BaseModel):
     fetcher: str
     # The url the event targets for fetching
     url: str
-    # Specific fetcher configuration (overridden by deriving event classes)
-    config: FetcherConfig = None
+    # Specific fetcher configuration (overridden by deriving event classes (FetcherConfig)
+    config: dict = None
     # Tenacity.retry - Override default retry configuration for this event     
     retry: dict = None
 
